﻿using PaintShopSchedulingCarrierChangeOptimizer.Solvers;

namespace PaintShopSchedulingCarrierChangeOptimizer
{
    /// <summary>
    /// Singleton class to create and retrieve CarrierChangeOptimization Algorithms 
    /// </summary>
    public class CarrierChangeOptimizerFactory 
    {
        private static CarrierChangeOptimizerFactory _instance;
        public ICarrierChangeOptimizer DefaultCarrierChangeOptimizer { set; private get; }

        private CarrierChangeOptimizerFactory()
        {
            // Use exact algorithm by default
            DefaultCarrierChangeOptimizer = new SimpleLongestCommonSubsequenceCarrierChangeOptimizer();
        }

        /// <summary>
        /// Get the singleton instance
        /// </summary>
        public static CarrierChangeOptimizerFactory Instance
        {
            get
            {
                if (_instance == null)
                {
                    _instance = new CarrierChangeOptimizerFactory();
                }
                return _instance;
            }
        }

        /// <summary>
        /// Return the configured default carrier change optimization algorithm.  
        /// </summary>
        /// <returns>An instance for the configured default carrier change optimization algorithm.</returns>
        public ICarrierChangeOptimizer GetDefaultCarrierChangeOptimizer()
        {
            return DefaultCarrierChangeOptimizer;
        }

        /// <summary>
        /// Gets an exact carrier change optimization algorithm based on an algorithm for the simple longest common subsequence problem.
        /// The algorithm has an O(n^2) runtime complexity.
        /// </summary>
        /// <returns>An instance for an exact carrier change optimization algorithm.</returns>
        public ICarrierChangeOptimizer GetSimpleLongestCommonSubsequenceCarrierChangeOptimizer()
        {
            return new SimpleLongestCommonSubsequenceCarrierChangeOptimizer();
        }

    }
}
