﻿using System.Collections.Generic;
using PaintShopSchedulingSimpleTypes.SimpleTypes;

namespace PaintShopSchedulingSimpleTypes
{
    /// <summary>
    /// Represents a problem instance in a simple format.
    /// </summary>
    public class SimpleInstance 
    {
        /// <summary>
        /// Number of rounds in the schedule (excluding the history round)
        /// </summary>
        public int NumberOfRounds;
        public int MinCapacity;
        public int MaxCapacity;

        /// <summary>
        /// Collection containing all colors, color ids have to be numbered from 0 -- Colors.Count-1
        /// </summary>
        public ICollection<SimpleColor> Colors;
        /// <summary>
        /// Collection containing all materials, material ids have to be numbered from 0 -- Materials.Count-1
        /// </summary>
        public ICollection<SimpleMaterial> Materials;

        /// <summary>
        /// Collection containing all demands, demand ids have to be numbered from 0 -- Demands.Count-1
        /// </summary>
        public ICollection<SimpleDemand> Demands;
        /// <summary>
        /// Collection containing all carrier types, carrier type ids have to be numbered from 0 -- Carriers.Count-1
        /// </summary>
        public ICollection<SimpleCarrierType> Carriers;
        /// <summary>
        /// Collection containing all configurations, configuration ids have to be numbered from 0 -- Carriers.Count-1
        /// </summary>
        public ICollection<SimpleCarrierConfiguration> Configurations;
        public IList<SimpleHistoryRoundPosition> HistoryRound;

        // note: CarrierInfos contains Availability, Min- and Max-Block Sizes
        public ICollection<SimpleCarrierTypeInformation> CarrierTypeInfos;
        public ICollection<SimpleForbiddenCarrierTypeSequence> ForbiddenCarrierSequences;
        public ICollection<SimpleForbiddenColorSequence> ForbiddenColorSequences;
        public ICollection<SimpleColorTransitionCost> ColorTransitionCosts;

        /// <summary>
        /// Configuration id to configuration name lookup
        /// </summary>
        public IList<string> ConfigurationNames;
        /// <summary>
        /// Color id to color name lookup
        /// </summary>
        public IList<string> ColorNames;
        /// <summary>
        /// CarrierType id to carrier type name lookup
        /// </summary>
        public IList<string> CarrierTypeNames;
        /// <summary>
        /// Material id to material name lookup
        /// </summary>
        public IList<string> MaterialNames;
    }
}
