﻿using System.Collections.Generic;
using PaintShopSchedulingSimpleTypes;

namespace SimpleSolutionValidator.SolutionEvaluator
{
    /// <summary>
    /// Evaluates carrier changes for a given solution
    /// </summary>
    public interface ICarrierChangeEvaluator
    {
        /// <summary>
        /// Evaluate number of carrier changes.
        /// </summary>
        /// <param name="solution">Solution that should be evaluated.</param>
        void Evaluate(ISimpleSolution solution);

        /// <summary>
        /// Returns the total number of carrier changes in this solution.
        /// </summary>
        int GetTotalNumberOfChanges();

        /// <summary>
        /// Return the squared number of changes, where the total changes are the sum of all squared changes per round.
        /// </summary>
        int GetSquaredNumberOfChanges();

        /// <summary>
        /// Get the evaluated carrier changes per round.
        /// </summary>
        IList<int> GetCarrierChangesPerRound();

        /// <summary>
        /// Get the evaluated carrier changes after each round
        /// </summary>
        IList<int> GetCarrierChangesAfterEachRound();

        /// <summary>
        /// Get the average amount of carrier changes per round.
        /// </summary>
        double GetAverageCarrierChangesPerRound();

        /// <summary>
        /// Gets the maximum number of changes for all rounds
        /// </summary>
        int GetMaxChangesBetweenRounds();

        /// <summary>
        /// Get Carrier Change Variance
        /// </summary>
        double GetCarrierChangeVariance();
    }
}
