﻿using System.Collections.Generic;
using PaintShopSchedulingSimpleTypes;
using PaintShopSchedulingSimpleTypes.SimpleTypes;

namespace SimpleSolutionValidator.SolutionEvaluator
{
    /// <summary>
    /// Evaluates forbidden carrier type sequence violations for solutions.
    /// </summary>
    public interface IForbiddenCarrierTypeSequencesEvaluator
    {
        /// <summary>
        /// Evaluates a given solution regarding forbidden carrier type sequences.
        /// </summary>
        /// <param name="forbiddenCarrierTypeSequences">Collection containing all forbidden carrier type sequences.</param>
        /// <param name="solution">Solution that should be evaluated.</param>
        void Evaluate(ICollection<SimpleForbiddenCarrierTypeSequence> forbiddenCarrierTypeSequences, ISimpleSolution solution);

        /// <summary>
        /// Get the number of violations from the last evaluation.
        /// </summary>
        int GetTotalViolations();

        /// <summary>
        /// Get the number of violations per round from the last evaluation.
        /// </summary>
        IList<int> GetViolationsPerRound();
    }
}