﻿using System.Collections.Generic;
using PaintShopSchedulingSimpleTypes;
using PaintShopSchedulingSimpleTypes.SimpleTypes;

namespace SimpleSolutionValidator.SolutionEvaluator
{
    /// <summary>
    /// Evaluates a given solution regarding max block size violations.
    /// </summary>
    public interface IMaxBlockSizeEvaluator
    {
        /// <summary>
        /// Evaluate given solution regarding max block size violations
        /// </summary>
        /// <param name="carrierTypeInformations">Information about carrier types including, max block sizes</param>
        /// <param name="solution">The solution that should be evaluated.</param>
        void Evaluate(ICollection<SimpleCarrierTypeInformation> carrierTypeInformations, ISimpleSolution solution);

        /// <summary>
        /// Get the total violations from the last Evaluate call
        /// </summary>
        int GetTotalViolations();

        /// <summary>
        /// Get violations per round from the last Evaluate call.
        /// Violations will be counted in the round where the violated block ends.
        /// </summary>
        IList<int> GetViolationsPerRound();
    }
}