﻿using System.Collections.Generic;
using PaintShopSchedulingSimpleTypes;
using PaintShopSchedulingSimpleTypes.SimpleTypes;

namespace SimpleSolutionValidator.SolutionEvaluator
{
    /// <summary>
    /// Evalutes a candidate solution regarding min block size violations 
    /// </summary>
    public interface IMinBlockSizeEvaluator
    {
        /// <summary>
        /// Evaluates a solution regarding min block size violations.
        /// </summary>
        /// <param name="carrierTypeInformations">Collection containing information about carrier types, including the allowed min block sizes.</param>
        /// <param name="solution">The solution that should be evaluated.</param>
        void Evaluate(ICollection<SimpleCarrierTypeInformation> carrierTypeInformations, ISimpleSolution solution);

        /// <summary>
        /// Gets the total violations from the last Evaluate call.
        /// </summary>
        int GetTotalViolations();

        /// <summary>
        /// Gets the violations per round from the last Evaluate call.
        /// Violations will be counted in the round where the violated block ends.
        /// </summary>
        IList<int> GetViolationsPerRound();
    }
}