﻿using System.Collections.Generic;
using PaintShopSchedulingSimpleTypes;

namespace SimpleSolutionValidator.SolutionEvaluator
{
    /// <summary>
    /// Evaluates the number of round capacity violations for a given solution
    /// </summary>
    public interface IRoundCapacityEvaluator
    {
        /// <summary>
        /// Evaluates the round capacity violations for a given solution
        /// </summary>
        /// <param name="minCapacity">The minimum carrier capacity per round.</param>
        /// <param name="maxCapacity">The maximum carrier capacity per round.</param>
        /// <param name="solution">Solution that should be evaluated.</param>
        void Evaluate(int minCapacity, int maxCapacity, ISimpleSolution solution);

        /// <summary>
        /// Gets the number of violations from the last Evaluate call.
        /// </summary>
        int GetTotalViolations();

        /// <summary>
        /// Gets the violations per round from the last Evaluate call.
        /// </summary>
        IList<int> GetViolationsPerRound();
    }
}