﻿using System.IO;
using PaintShopSchedulingSimpleTypes;

namespace SimpleSolutionValidator.SolutionEvaluator
{
    /// <summary>
    /// Evaluates a simple solution based on a given simple instance
    /// </summary>
    public interface ISimpleSolutionEvaluator
    {
        /// <summary>
        /// Evaluate a given solution and print results using a given text writer. 
        /// </summary>
        /// <param name="instance">Instance associated to the given solution.</param>
        /// <param name="solution">Solution that should be evaluated.</param>
        /// <param name="textWriter">TextWriter which will be used to print the results.</param>
        void EvaluateSolution(SimpleInstance instance, ISimpleSolution solution, TextWriter textWriter);

        /// <summary>
        /// Evaluate a given solution and print a single line result (hard constraint violations,cost) for benchmarks
        /// </summary>
        /// <param name="instanceName">Name of the instance which should be included in the output line.</param>
        /// <param name="instance">Instance associated to the given solution.</param>
        /// <param name="solution">Solution that should be evaluated.</param>
        /// <param name="textWriter">TextWriter which will be used to print the single line result.</param>
        void EvaluateSolutionSingleLineCost(string instanceName, SimpleInstance instance, ISimpleSolution solution, TextWriter textWriter);
    }
}
