﻿using System.Collections.Generic;
using System.Linq;
using PaintShopSchedulingSimpleTypes;

namespace SimpleSolutionValidator.SolutionEvaluator
{
    public class RoundCapacityEvaluator : IRoundCapacityEvaluator
    {
        private int _totalViolations;
        private IList<int> _violationsPerRound;
        public void Evaluate(int minCapacity, int maxCapacity, ISimpleSolution solution)
        {
            _totalViolations = 0;
            _violationsPerRound = Enumerable.Repeat(0, solution.NumberOfRounds - 1).ToList();

            for (int roundIndex = 1; roundIndex < solution.NumberOfRounds; roundIndex++) {
                int numberOfCarriersInRound = solution.GetNumberOfCarriersInRound(roundIndex);

                int violationsInRound = 0;
                if (numberOfCarriersInRound < minCapacity) {
                    violationsInRound =  minCapacity - numberOfCarriersInRound;
                    System.Console.WriteLine("The minimum number of carriers per round is " + minCapacity + ", but only " +
                                             numberOfCarriersInRound + " are scheduled in round " + roundIndex);
                }
                if (numberOfCarriersInRound > maxCapacity) {
                    violationsInRound = numberOfCarriersInRound - maxCapacity;
                    System.Console.WriteLine("The maximum number of carriers per round is " + maxCapacity + ", but " +
                                             numberOfCarriersInRound + " are scheduled in round " + roundIndex);
                }

                _totalViolations += violationsInRound;
                _violationsPerRound[roundIndex - 1] = violationsInRound;
            }
        }

        public int GetTotalViolations()
        {
            return _totalViolations;
        }

        public IList<int> GetViolationsPerRound()
        {
            return _violationsPerRound;
        }
    }
}